embassy-usb-host

Crates

git

Versions

default

Flavors

BusState

Struct BusState 

pub struct BusState { /* private fields */ }
Shared bus-wide state used by a BusHandle.

Holds the in-use USB device addresses (1–127) and an async mutex used to serialise enumerations on a single bus.

Addresses greater than 127 are not issued because their behavior is not specified (USB 2.0 9.4.6).

Implementations

Source

impl BusState

pub const fn new() -> Self

Create new, empty bus state.

pub fn free_address(&self, addr: u8)

Release a previously allocated device address.

No-op if the address is out of range or was not marked as in use.