pub struct BusState { /* private fields */ }Expand description
Shared bus-wide state used by a BusHandle.
Holds the in-use USB device addresses (1–127) and an async mutex used to serialise enumerations on a single bus.
Addresses greater than 127 are not issued because their behavior is not specified (USB 2.0 9.4.6).
Implementations